# pyLoDStorage
python List of Dict (Table) Storage library

[![Documentation Status](https://readthedocs.org/projects/pylodstorage/badge/?version=latest)](https://pylodstorage.readthedocs.io/en/latest/?badge=latest)
[![pypi](https://img.shields.io/pypi/pyversions/pyLoDStorage)](https://pypi.org/project/pyLoDStorage/)
[![Github Actions Build](https://github.com/WolfgangFahl/pyLoDStorage/workflows/Build/badge.svg?branch=master)](https://github.com/WolfgangFahl/pyLoDStorage/actions?query=workflow%3ABuild+branch%3Amaster)
[![PyPI Status](https://img.shields.io/pypi/v/pyLoDStorage.svg)](https://pypi.python.org/pypi/pyLoDStorage/)
[![Downloads](https://pepy.tech/badge/pyLoDStorage)](https://pepy.tech/project/pyLoDStorage)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyLoDStorage.svg)](https://github.com/WolfgangFahl/pyLoDStorage/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyLoDStorage.svg)](https://github.com/WolfgangFahl/pyLoDStorage/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/pyLoDStorage.svg)](https://www.apache.org/licenses/LICENSE-2.0)

What it is
==========
pyLoDStorage allows to store table like data (List of Dicts) via  

- Sqlite3
- JSON
- SPARQL

Installation
============
```bash
pip install pylodstorage
```

Get Sources 
===========
```bash
git clone https://github.com/WolfgangFahl/pyLoDStorage
cd pyLodStorage
scripts/install
```

Testing
=======
```bash
scripts/test
```

Usage
=====
see [test cases](https://github.com/WolfgangFahl/pyLoDStorage/tree/master/tests)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/PyLoDStorage)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
